#!/usr/bin/env python3

'''
This script is used to generate an installation report in pdf format.
Installation Report PDF generated by this script contains the following information:
vCenter Details
Nodes' Details like Name, IP Address, Hypervisor
Logging Service Details
Consul & Vault Service Details
IBE Service Details
VM information
'''
import argparse
import yaml
import socket
import jinja2
import sys
from datetime import datetime
import pdfkit
import os
import logging
import hcl
import configparser
from time import strftime
from ansible.parsing.dataloader import DataLoader
from ansible.inventory.manager import InventoryManager
from . logging_monitoring_details import LoggingMonitoringDetails
from . vmware_details import VmwareDetails
from . hsop_services import HsopServices
from . hsop_version import HsopVersion
from . import global_vars

HsopVersion = HsopVersion()
HsopServices = HsopServices()
VmwareDetails = VmwareDetails()
LoggingMonitoringDetails = LoggingMonitoringDetails()

def get_inventory_details():
    if not os.path.exists(global_vars.INVENTORY_FILE):
        log_and_raise_exception('Inventory file {0} does not exist'.format(global_vars.INVENTORY_FILE))
    logging.debug('Parsing Inventory file {0}'.format(global_vars.INVENTORY_FILE))
    data_loader = DataLoader()
    inventory = InventoryManager(loader = data_loader,sources=[global_vars.INVENTORY_FILE])
    return inventory.get_groups_dict()

def get_config_details(CONFIG_FILE):
    if not os.path.exists(CONFIG_FILE):
        log_and_raise_exception('Conf file {0} does not exist'.format(CONFIG_FILE))
    logging.debug('Parsing config file {0}'.format(CONFIG_FILE))
    with open(CONFIG_FILE, 'r') as fp:
        config = yaml.safe_load(fp)
        return config

def get_ansible_cfg(ANSIBLE_CFG):
   if not os.path.exists(ANSIBLE_CFG):
      log_and_raise_exception('Conf file {0} does not exist'.format(ANSIBLE_CFG))
   logging.debug('Parsing config file {0}'.format(ANSIBLE_CFG))
   configParser = configparser.RawConfigParser()
   configParser.read(ANSIBLE_CFG)
   ansible_cfg = dict(configParser.items('defaults'))
   return ansible_cfg

def get_values_for_report(config_dict,inventory_dict,ansible_dict,BUILD_CONF,ansible_vars_dict,hsop_repoPath):
    '''
    Gets the data needed to fill the report template.
    Data includes vCenter information, Core service details

    '''
    hsop_version=HsopVersion.get_hsop_version(inventory_dict,config_dict,BUILD_CONF)
    logging.debug('Getting Values for the report template')
    report_values = {}
    report_generation_time = datetime.now().strftime("%d-%m-%Y %H:%M:%S")
    report_values['report_generation_time'] = report_generation_time
    logging.debug('Report ie being generated at {0}'.format(report_generation_time))
    infra_details={}   
    vmware_infra_details = VmwareDetails.get_infra_details_for_report(config_dict)
    report_values.update(vmware_infra_details)
    service_details = HsopServices.get_service_details(config_dict, inventory_dict, ansible_dict, ansible_vars_dict, hsop_repoPath)
    report_values['service_details'] = service_details
    report_values['iac_deployment_time'] = LoggingMonitoringDetails.get_deployment_time_for_logging(config_dict)
    report_values['hsop_serialId'] = config_dict['hsop_serial_number']
    report_values['vcip'] = socket.gethostbyname(config_dict['vsphere_server'].strip('\"'))
    logging.debug('Values for the report : {0}'.format(report_values))
    report_values['hsop_version'] = hsop_version
    return report_values

def generate_report_in_html(repo_path,report_values, html_file):
    '''
    Updates the HTML report template with values and generates report in HTML format
    :param report_values
    :param html_file
    '''
    logging.debug('Started generating report in HTML')
    templateLoader = jinja2.FileSystemLoader(searchpath=repo_path+"/dhr/dhrpackage/template")
    templateEnv = jinja2.Environment(loader=templateLoader)
    TEMPLATE_FILE = "installation_report_template.html.j2"
    template = templateEnv.get_template(TEMPLATE_FILE)
    output_text = template.render(report_values)
    html_file = open(html_file, 'w')
    html_file.write(output_text)
    html_file.close()
    logging.debug('Completed generating report in HTML')

def generate_report_in_pdf(html_file, pdf_file):
    '''
    Generates report in PDF fromat from HTML file
    :param html_file
    :param pdf_file
    '''
    logging.debug('Generating report in pdf format')
    config = pdfkit.configuration()
    pdfkit.from_file(html_file, pdf_file, configuration=config)
    logging.debug('Completed generation of report in pdf format')

def log_and_raise_exception(err_msg):
    '''
    Logs the error message and raises an exception
    :param err_msg
    '''
    logging.error(err_msg)
    raise Exception(err_msg)

def main():
    '''
        Entry method for the script
        :return: None
    '''   
    parser = argparse.ArgumentParser(description='DHR with repo path as input parameters.Example:python __main__.py  /home/hsop-svc/HSOP')
    parser.add_argument("HSOPRepoPath", help="Absolute Path for HSOP repo. Ex: /home/hsop-svc/HSOP")
    args = parser.parse_args()
    if len(sys.argv) == 1:
       os.system("python " + sys.argv[0] + " -h")
       exit()	
    BUILD_CONF  = args.HSOPRepoPath+"/build_version.conf"
    logs_path = args.HSOPRepoPath+"/dhr/logs"
    reports_path = args.HSOPRepoPath+"/dhr/reports"
    try:
        os.makedirs(logs_path, exist_ok=True)
    except Exception as e:
        print('Exception occurred while creating directory {0} : {1}'.format(logs_path, str(e)))
        sys.exit(1)
    logging.basicConfig(level=logging.DEBUG, format='%(asctime)s %(levelname)s %(message)s',
                        handlers=[
                            logging.FileHandler("{0}/{1}".format(logs_path, strftime("{0}_{1}.log".format(global_vars.REPORT_PREFIX, global_vars.REPORT_SUFFIX_FORMAT)))),
                            logging.StreamHandler()
                        ])
    try:
        os.makedirs(reports_path, exist_ok=True)
    except Exception as e:
        log_and_raise_exception('Exception occurred while creating directory {0} : {1}'.format(global_vars.reports_path, str(e)))
    html_file_name = '{0}_{1}.html'.format(global_vars.REPORT_PREFIX, datetime.now().strftime(global_vars.REPORT_SUFFIX_FORMAT))
    html_file = os.path.join(reports_path, html_file_name)
    pdf_file = html_file.replace('html', 'pdf')
    inventory_dict = get_inventory_details()
    config_dict = get_config_details(args.HSOPRepoPath+global_vars.INPUT_VAR_FILE)
    ansible_dict = get_ansible_cfg(args.HSOPRepoPath+global_vars.ANSIBLE_CFG)
    ansible_vars_dict = get_config_details(args.HSOPRepoPath+global_vars.ANSIBLE_VAR_FILE)
    report_values = get_values_for_report(config_dict, inventory_dict, ansible_dict, BUILD_CONF, ansible_vars_dict, args.HSOPRepoPath)
    generate_report_in_html(args.HSOPRepoPath, report_values, html_file)
    generate_report_in_pdf(html_file, pdf_file)
    logging.debug('Report {0} has been generated successfully'.format(pdf_file))
    print(html_file_name)
    sys.exit(0) 
   
if __name__ == '__main__':
    main()



#!/usr/bin/env python3

import os
import yaml
import paramiko
import logging
import requests
from . log_exception import LogException
class HsopVersion:
   LogException = LogException()
   def get_hsop_version(self,inventory_dict,config_dict,BUILD_CONF):
       try:
           hsop_version = None
           logging.debug('Getting HSOP version details')
           with open(BUILD_CONF, 'r') as file:
               line = file.readline()
               if line.startswith(('HSoP','hsop','HSOP')):
                   hsop_version = line
               else:
                   logging.error('HSOP version not captured in : {0}'.format(BUILD_CONF_FILE))
           return hsop_version

       except Exception as e:
           self.LogException.log_and_raise_exception('Exception occurred while checking for build_version.conf file :{0}'.format(str(e)))           



#!/usr/bin/env python3

import os
import yaml
import paramiko
import logging
import requests
from . logging_monitoring_details import LoggingMonitoringDetails
from . ibe_details import IbeDetails
from . log_exception import LogException
from datetime import datetime

class HsopServices:
   LoggingMonitoringDetails = LoggingMonitoringDetails()
   IbeDetails = IbeDetails()
   LogException = LogException()
   def get_service_details(self, config_dict, inventory_dict, ansible_dict, ansible_vars_dict,hsop_repoPath):
       logging.debug('Getting Core services details')
       try:           
           key_file = hsop_repoPath+"/ansible/"+ansible_dict['private_key_file'].strip("../")            
           service_details = []
           consul_details = self.LoggingMonitoringDetails.get_consul_version(inventory_dict, config_dict, ansible_dict,key_file)
           if len(consul_details) > 0:
               service_details.append(consul_details)
           vault_details = self.LoggingMonitoringDetails.get_vault_service_details(inventory_dict, config_dict, ansible_dict, key_file)
           if len(vault_details) > 0:
               service_details.append(vault_details)
           logging_details = self.LoggingMonitoringDetails.get_logging_service_details(inventory_dict, config_dict, ansible_dict, ansible_vars_dict, key_file)
           if len(logging_details) > 0:
               service_details.append(logging_details)
           ibe_details = self.IbeDetails.get_ibe_details(inventory_dict)
           if len(ibe_details) > 0:
               service_details.append(ibe_details)
           return service_details
       except Exception as e:
           self.LogException.log_and_raise_exception('Exception occurred while getting Core service details Details : {0}'.format(str(e)))


#!/usr/bin/env python3

import os
import hcl
import yaml
import paramiko
import logging
import requests
import subprocess
import configparser
from os import listdir
from datetime import datetime
from datetime import timedelta
from os.path import isfile, join
from subprocess import Popen, PIPE
from time import sleep
from . log_exception import LogException
from . import global_vars

class LoggingMonitoringDetails:
   LogException = LogException()
   def get_vault_service_details(self,inventory_dict, config_dict, ansible_dict,key_file):
       try:
           logging.debug('Getting Vault Service details')
           vault_service = {}
           if ((inventory_dict['vault_server'] is not None and len(inventory_dict['vault_server']) > 0)):
               vault_ip = inventory_dict['vault_server'][0]
               vault_service['name'] = 'Vault'
               vault_service['components'] = []
               ssh_client = self.get_ssh_client(vault_ip,key_file,ansible_dict['remote_user'])
               command = 'vault --version'
               (stdin, stdout, stderr) = ssh_client.exec_command(command,get_pty=True)
               exit_status = stdout.channel.recv_exit_status()
               logging.debug("output for vault command : {0}".format(stdout))
               logging.debug("Error for vault command : {0}".format(stderr))
               vault_version = None
               for line in stdout.readlines():
                  if line.startswith('Vault'):
                     vault_version = line
                     break
               if vault_version is not None:
                   vault_service['components'].append(vault_version)
               ssh_client.close()
           else:
               logging.error('vault component not found in inventory')
           return vault_service
       except Exception as e:
           self.LogException.log_and_raise_exception('Exception occurred while getting vault service details : ' + str(e))

   def get_logging_service_details(self,inventory_dict, config_dict, ansible_dict, ansible_vars_dict, key_file):
       try:
           logging.debug('Getting Logging Service details')
           logging_service = {}
           if ((inventory_dict['aggregator'] is not None and len(inventory_dict['aggregator']) > 0) or (inventory_dict['elasticsearch'] is not None and len(inventory_dict['elasticsearch']) > 0) or (inventory_dict['kibana'] is not None and len(inventory_dict['kibana']) > 0)):
               logging_service['name'] = 'Logging'
               logging_components = []
               is_single_node = True if config_dict['single_node'].strip('\"').lower() == 'yes' else False
               tdagent_version = self.get_tdagent_version(key_file, inventory_dict, ansible_dict)
               if tdagent_version is not None:
                   logging_components.append(tdagent_version)
            
               elasticsearch_version = self.get_elasticsearch_version(is_single_node, inventory_dict, ansible_vars_dict['elasticsearch_user'], ansible_vars_dict['elasticsearch_password'])
               if elasticsearch_version is not None:
                   logging_components.append(elasticsearch_version)

               kibana_version = self.get_kibana_version(is_single_node, key_file, inventory_dict, ansible_dict)
               if kibana_version is not None:
                   logging_components.append(kibana_version)

               logging_service['components'] = logging_components
               logging.debug('Logging Service details : {0}'.format(logging_service))
           else:
               logging.error('Logging components not found in inventory')
           return logging_service
       except Exception as e:
           self.LogException.log_and_raise_exception('Exception occurred while getting logging service details : ' + str(e))
   def get_consul_version(self,inventory_dict, config_dict, ansible_dict, key_file):
       try:
           consul_ip = None
           consul_service = {}
           if(inventory_dict['consul_servers'] is not None and len(inventory_dict['consul_servers']) > 0):
               consul_ip = inventory_dict['consul_servers'][0]
               consul_service['name'] = 'Consul'
               consul_service['components'] = []
               command = 'consul version'
               if(consul_ip =='localhost'):
                  cmd=subprocess.Popen(['consul', 'version'], stdin=PIPE, stdout=PIPE, stderr=PIPE)
                  (stdout, stderr) = cmd.communicate()
                  logging.debug("output for consul command : {0}".format(stdout))
                  logging.debug("Error for consul command : {0}".format(stderr))
                  consul_version=stdout.splitlines()[0].decode("utf-8")
                  consul_service['components'].append(consul_version)
               else:
                  ssh_client = self.get_ssh_client(consul_ip,key_file,ansible_dict['remote_user'])
                  (stdin, stdout, stderr) = ssh_client.exec_command(command,get_pty=True)
                  logging.debug("output for consul command : {0}".format(stdout))
                  logging.debug("Error for consul command : {0}".format(stderr))
                  consul_version = None
                  for line in stdout.readlines():
                
                      if line.startswith('Consul'):
                        consul_version = line
                        consul_service['components'].append(consul_version)
                        break
                  if consul_version is None:
                     logging.error("consul version not found in {0}".format(consul_ip))
                  ssh_client.close()
       
           else: 
               logging.error('consul ip not found in inventory')
           return consul_service
       except Exception as e:
           self.LogException.log_and_raise_exception('Exception occurred while getting consul service details : ' + str(e))

   def get_tdagent_version(self,key_file, inventory_dict, ansible_dict):
       if (inventory_dict['aggregator'] is not None and len(inventory_dict['aggregator']) > 0):
           aggregator_ip = inventory_dict['aggregator'][0]
           ssh_client = self.get_ssh_client(aggregator_ip, key_file,ansible_dict['remote_user'] )
           command = 'rpm -q td-agent'
           (stdin, stdout, stderr) = ssh_client.exec_command(command)
           logging.debug("output for td-agent command : {0}".format(stdout))
           logging.debug("Error for td-agent command : {0}".format(stderr))
           tdagent_version = None
           for line in stdout.readlines():
               if line.startswith('td-agent'):
                   tdagent_version =  line
                   break
           if tdagent_version is None:
               logging.error("td-agent version not found in {0}".format(aggregator_ip))
           ssh_client.close()
           return tdagent_version
       else:
           logging.error('aggregator group not found in inventory')

   def get_elasticsearch_version(self,is_single_node, inventory_dict, elastic_user, elastic_password):
       elasticsearch_ip = None
       if(is_single_node is True and inventory_dict['aggregator'] is not None and len(inventory_dict['aggregator']) > 0):
           elasticsearch_ip = inventory_dict['aggregator'][0]
       elif(is_single_node is False and inventory_dict['elasticsearch'] is not None and len(inventory_dict['elasticsearch']) > 0):
           elasticsearch_ip = inventory_dict['elasticsearch'][0]
       else:
           logging.error('elastic search ip not found in inventory')
           return

       response = requests.get('https://{0}:9200'.format(elasticsearch_ip),verify=False,auth=(elastic_user, elastic_password))
       response.raise_for_status()
       elastic_details = response.json()
       if 'version' in elastic_details:
           return 'elasticsearch-{0}'.format(elastic_details['version']['number'])
       else:
           logging.error("elasticsearch version not found in {0}".format(elasticsearch_ip))

   def get_kibana_version(self, is_single_node, key_file, inventory_dict, ansible_dict):
       kibana_ip = None
       if(is_single_node is True and inventory_dict['aggregator'] is not None and len(inventory_dict['aggregator']) > 0):
           kibana_ip = inventory_dict['aggregator'][0]
       elif(is_single_node is False and inventory_dict['kibana'] is not None and len(inventory_dict['kibana']) > 0):
           kibana_ip = inventory_dict['kibana'][0]
       else:
           logging.error('kibana ip not found in inventory')
       ssh_client = self.get_ssh_client(kibana_ip, key_file,ansible_dict['remote_user'])
       command = 'rpm -q kibana'
       (stdin, stdout, stderr) = ssh_client.exec_command(command)
       logging.debug("output for kibana command : {0}".format(stdout))
       logging.debug("Error for kibana command : {0}".format(stderr))
       kibana_version = None
       for line in stdout.readlines():
           if line.startswith('kibana'):
               kibana_version = line
               break
       if kibana_version is None:
           logging.error("kibana version not found in {0}".format(kibana_ip))
       ssh_client.close()
       return kibana_version

   def get_ssh_client(self, ip_address, key_file, host_user):
       try:
           logging.debug('Getting SSH connection to {0}'.format(ip_address))
           ssh_client = paramiko.SSHClient()
           ssh_client.set_missing_host_key_policy(paramiko.AutoAddPolicy())
           ssh_client.connect(ip_address, port=22, username=host_user, key_filename=key_file)
           logging.debug('Got SSH connection to {0}'.format(ip_address))
           return ssh_client
       except Exception as e:
           self.LogException.log_and_raise_exception('Exception occurred while getting ssh client : ' + str(e))

   def get_deployment_time_for_logging(self, config_dict):
       latest_log_file =self.get_latest_logging_deployment_logfile()
       if latest_log_file is not None  and len(latest_log_file) > 0:
           deployment_time = self.find_logging_deployment_time_from_log(os.path.join(global_vars.IAC_LOG_PATH, latest_log_file),config_dict)['execution_time']
           start_time = (self.find_logging_deployment_time_from_log(os.path.join(global_vars.IAC_LOG_PATH, latest_log_file),config_dict)['start_time']).strip()
           if(deployment_time == None):
               now = datetime.now()
               current_time = now.strftime("%H:%M:%S")
               fmt='%H:%M:%S'
               diff = datetime.strptime(current_time,fmt)-datetime.strptime(start_time,fmt)
               deployment_time = self.format_time(diff.seconds)        
           return deployment_time

   def get_latest_logging_deployment_logfile(self):
       try:
           logging.debug('Getting the latest logging deployment log from {0}'.format(global_vars.IAC_LOG_PATH))
           latest_log_file_name = ''
           if os.path.exists(global_vars.IAC_LOG_PATH):
               log_files = [f for f in listdir(global_vars.IAC_LOG_PATH) if isfile(join(global_vars.IAC_LOG_PATH, f))]
               datemask = "%Y-%m-%d_%H:%M:%S"
               for logfile in log_files:
                   if(logfile.startswith(global_vars.IAC_LOG_FILE_NAME_PREFIX)):
                       if(latest_log_file_name == ''):
                           latest_log_file_name = logfile
                           continue       
                       logfile_time_str = logfile.split("_",2)[2].strip('.log')                   
                       logfile_time_dt = datetime.strptime(logfile_time_str, datemask)
                       latest_logfile_time_str = latest_log_file_name.split("_",2)[2].strip('.log')
                       latest_logfile_time_dt = datetime.strptime(latest_logfile_time_str, datemask)
                       if(logfile_time_dt > latest_logfile_time_dt):
                           latest_log_file_name = logfile
               if latest_log_file_name == '':
                   logging.error("IaC Deployment log file with prefix {0} not found".format(global_vars.IAC_LOG_FILE_NAME_PREFIX))
               logging.debug('Latest IaC deployment log file {0}'.format(latest_log_file_name))
               return latest_log_file_name
           else:
               logging.error("IaC Logs directory {0} not found".format(global_vars.IAC_LOG_PATH))
       except Exception as e:
           self.LogException.log_and_raise_exception('Exception occurred while getting latest IaC deployment log : ' + str(e))

   def find_logging_deployment_time_from_log(self,log_file,config_dict):
       logging.debug('Finding logging deployment time')
       start_time = None
       execution_time = None
       with open(log_file, 'r') as f:
           while True:
               line = f.readline()
               if ('Execution started' in line):
                  start_time_line = line
                  start_line_array = start_time_line.split(' ')
                  start_time = start_line_array[len(start_line_array) - 1]
               if line == '':
                   break

               if (global_vars.IAC_SUCCESS_MESSAGE) in line:
                   execution_time_line = f.readline()
                   line_array = execution_time_line.split(':')
                   execution_time = line_array[len(line_array) - 1]

           return {'start_time':start_time,'execution_time':execution_time}
       logging.error("Successful Deployment Time for IaC could not be found")

   def format_time(self,seconds):
       hours=str(seconds//3600)
       mins=str((seconds%3600)//60)
       sec=str((seconds%3600)%60)[:2]
       time_formatted = "{}hr {}mins {}sec".format(hours, mins,sec)
       return time_formatted



INPUT_VAR_FILE = "/wrapper-scripts/input.yml"
INVENTORY_FILE = "/etc/philips/conf/inventory"
ANSIBLE_CFG = "/ansible/ansible.cfg"
ANSIBLE_VAR_FILE = "/ansible/group_vars/linux.yml"
REPORT_PREFIX = "hsop_installation_report" #Name of the generated report in the format installation_report_%Y%m%d_%H%M%S.pdf
REPORT_SUFFIX_FORMAT = "%d%m%Y_%H%M%S" #suffix
IAC_LOG_PATH = '/var/log/philips'
IAC_LOG_FILE_NAME_PREFIX = 'hsop_'
IAC_SUCCESS_MESSAGE = 'Deployment is done!!'



import logging
class LogException:
   def log_and_raise_exception(self,err_msg):
   
      '''
      Logs the error message and raises an exception
      :param err_msg
      '''
      logging.error(err_msg)
      raise Exception(err_msg)
      
      
      



#!/usr/bin/env python3
import pyVim
import pyVmomi
from pyVmomi import vim
from pyVim.connect import SmartConnect,Disconnect
import requests
import os
import json
import logging
import socket
import atexit
import ssl
import time
from getmac import get_mac_address
from collections import namedtuple
from . log_exception import LogException
from . import global_vars

default_context = ssl._create_default_https_context
ssl._create_default_https_context = ssl._create_unverified_context
requests.packages.urllib3.disable_warnings()
PROVIDER = "VMWare-VCenter"
class VmwareDetails:
   LogException = LogException()    
   def get_infra_details_for_report(self,config_dict):
       esxi_user = config_dict['esxi_user'].strip('\"')
       esxi_password = config_dict['esxi_password'].strip('\"')
       vc_User = config_dict['vsphere_user'].strip('\"').replace('\\\\','\\')
       vc_Password = config_dict['vsphere_password'].strip('\"')
       vcip = config_dict['vsphere_server'].strip('\"')
       dc_id = config_dict['vsphere_datacenter'].strip('\"')
       logging.debug('Getting VCenter infra details')
       infra_details = {}
       vc_session_id = self.get_session_id(vcip,vc_User,vc_Password)
       rsPool = self.get_rsPool_id(vcip,config_dict['vsphere_resource_pool'].strip('\"'),vc_session_id)
       esxi_details = self.get_esxi_details(vcip,vc_User,vc_Password,dc_id,esxi_user,esxi_password)
       vc_details = self.get_vc_details(vcip,vc_User,vc_Password)
       vm_details = self.get_vm_details(vcip,'', vc_session_id)
       infra_details['vc_details'] = vc_details
       infra_details['esxi_details'] = esxi_details
       infra_details['vm_details'] = vm_details
       self.del_session_id(vcip,vc_session_id)
       return infra_details

   def get_vc_details(self, vcip, vc_User, vc_Password):
       try:
          logging.debug('Getting vCenter details')
          vc_details = {}
          vc_con = SmartConnect(host=vcip, user=vc_User, pwd=vc_Password)
          content = vc_con.RetrieveContent()
          vc_details['name'] = content.about.name
          vc_details['version'] = content.about.version
          vc_details['apiVer'] = content.about.apiVersion
          vc_details['hyperVisor'] = content.about.build
          atexit.register(Disconnect, vc_con)
          return vc_details
       except Exception as e:
           self.LogException.log_and_raise_exception('Exception occurred while getting vCenter details : ' + str(e))


   def get_esxi_details(self, vcip, vc_User, vc_Password, dc_id,esxi_user,esxi_password):
       try:
           logging.debug('Getting esxi details')
           host = {}
           host_details = []
           si = SmartConnect(host=vcip, user=vc_User, pwd=vc_Password)
           content = si.RetrieveContent()        
           objview = content.viewManager.CreateContainerView(content.rootFolder, [vim.Datacenter],True)
           dcList = objview.view
           objview.Destroy()
           for dc in dcList:
              if(dc.name==dc_id):
                 for cluster in dc.hostFolder.childEntity:
                    for hostObj in cluster.host:
                       host['name'] = hostObj.name
                       host['ipaddress'] = socket.gethostbyname(hostObj.name)
                       for i in range(len(hostObj.hardware.systemInfo.otherIdentifyingInfo)):
                          if ('ServiceTag' in hostObj.hardware.systemInfo.otherIdentifyingInfo[i].identifierType.key):
                             host['serviceTag'] = hostObj.hardware.systemInfo.otherIdentifyingInfo[i].identifierValue
                    
                       host['biosVer'] = hostObj.hardware.biosInfo.biosVersion
                       hostCon = SmartConnect(host=host['ipaddress'],user=esxi_user,pwd=esxi_password)
                       host['hyperVisor'] = hostCon.RetrieveContent().about.build
                       host_details.append(host.copy())
                       atexit.register(Disconnect, hostCon)
           return host_details
       except Exception as e:
           self.LogException.log_and_raise_exception('Exception occurred while getting esxi details : ' + str(e))

   def get_vm_details(self,vcip,rsPool,vc_session_id):
       try:
           logging.debug('Getting VM details')
           vm_details = []
           vms_url = 'https://{0}/rest/vcenter/vm?filter.power_states.1=POWERED_ON&filter.power_states.1=POWERED_OFF&filter.resource_pools.1={1}'.format(vcip,rsPool)
           #vms_url = 'https://{0}/rest/vcenter/vm?filter.resource_pools.1={1}'.format(vcip,rsPool)
           response = requests.get(vms_url, verify=False, headers={"vmware-api-session-id": vc_session_id})
           for dict in response.json()['value']:
               if('vm' in dict):
                   vm = {}
                   vm['hostname'] = dict['name']
                   vm_id = dict['vm']
                   vmip_url = 'https://{0}/rest/vcenter/vm/{1}/guest/identity'.format(vcip,vm_id)
                   vmip_response = requests.get(vmip_url, verify=False, headers={"vmware-api-session-id": vc_session_id})
                   vm_mac_response = requests.get('https://{0}/rest/vcenter/vm/{1}'.format(vcip,vm_id), verify=False, headers={"vmware-api-session-id": vc_session_id})
                   if 'ip_address' in vmip_response.json()['value']:
                       vm['ip_address'] = vmip_response.json()['value']['ip_address']
                       vm['os'] = vmip_response.json()['value']['full_name']['default_message']
                   else:
                       vm['ip_address'] = "IP not assigned/VMware tools not installed"
                       vm['os'] = "IP not assigned/VMware tools not installed"

                   vm_mac_details = []
                   for nic in vm_mac_response.json()['value']['nics']:
                       vm_mac_details.append(nic['value']['mac_address'].strip('\''))
                       vm['mac'] = vm_mac_details
                   vm_details.append(vm)
               else:
                   logging.error("No vms mapped to resource pool : {0}".format(rsPool))
           return vm_details
       except Exception as e:
           self.LogException.log_and_raise_exception('Exception occurred while getting VM details : ' + str(e))

   def get_session_id(self, vcip, vc_User, vc_Password):
       '''
       API call being made to get the session_id w
       :param vcip:
       :param vc_User:
       :param vc_Password:
       :return: vc_session_id
       '''
       logging.debug('Getting the VCenter session_id')
       try:
           url = 'https://{0}/rest/com/vmware/cis/session'.format(vcip)
           response = requests.post(url,auth=(vc_User, vc_Password),verify=False)
           vc_session_id = response.json()['value']
           return vc_session_id
       except Exception as e:
           self.LogException.log_and_raise_exception('vCenter session-id generation failed : ' + str(e))

   def del_session_id(self,vcip,vc_session_id):
      logging.debug('Deleting VCenter api session')
      try:
          url = 'https://{0}/rest/com/vmware/cis/{1}'.format(vcip,vc_session_id)
      except Exception as e:
          self.LogException.log_and_raise_exception('vCenter session-id deletion failed : ' + str(e))

   def get_rsPool_id(self,vcip,rsPool,vc_session_id):
       logging.debug('Getting Resource Pool ID')
       rsPool_id = None
       url = 'https://{0}/rest/vcenter/resource-pool?filter.names.1={1}'.format(vcip,rsPool)
       response = requests.get(url, verify=False, headers={"vmware-api-session-id": vc_session_id})
       rsPool_id = response.json()['value'][0]['resource_pool']
       if not rsPool_id:
           self.LogException.log_and_raise_exception('No corresponding resource pool found')
       return rsPool_id



#!/usr/bin/env python3

import os
import yaml
import paramiko
import logging
import requests
from . log_exception import LogException

class IbeDetails: 
   LogException = LogException()
   def get_ibe_details(self,inventory_dict):
       try:
           logging.debug('Getting IBE Service details')
           ibe_service = {}
           if inventory_dict['ibe'] is not None and len(inventory_dict['ibe']) > 0:
               ibe_ip = inventory_dict['ibe'][0]
               response = requests.get('http://{0}:4444/IBE/discovery'.format(ibe_ip))
               response.raise_for_status()
               ibe_details = response.json()
               ibe_service['name'] = 'IBE'
               ibe_service['components'] = []
               if 'productversion' in ibe_details:
                   productid = ibe_details['productid']
                   productversion = ibe_details['productversion']
                   ibe_service['components'].append(productid + '-' + productversion)
               logging.debug('IBE Service details : {0}'.format(ibe_service))
           else:
               logging.error('ibe group not found in inventory')
           
           return ibe_service
       except Exception as e:
           self.LogException.log_and_raise_exception('Exception occurred while getting IBE service details Details : {0}'.format(str(e)))           


from setuptools import setup
setup(name='hsopdhr',
version='0.1',
description='This package generates dhr reports of HSOP in html and pdf formats',
url='https://github.com/yarlagadda1990/test',
author='yarlagadda',
author_email='yarlagadda.anusha@gmail.com',
license='',
packages=['dhrpackage'],
zip_safe=False,
entry_points={'console_scripts': ['hsopdhr = dhrpackage.__main__:main'] },)
